summaryrefslogtreecommitdiffstats
path: root/kalarm/editdlg.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /kalarm/editdlg.cpp
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kalarm/editdlg.cpp')
-rw-r--r--kalarm/editdlg.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kalarm/editdlg.cpp b/kalarm/editdlg.cpp
index acb7df63..7df52956 100644
--- a/kalarm/editdlg.cpp
+++ b/kalarm/editdlg.cpp
@@ -129,10 +129,10 @@ inline TQString recurText(const KAEvent& event)
{
TQString r;
if (event.repeatCount())
- r = TQString::fromLatin1("%1 / %2").tqarg(event.recurrenceText()).tqarg(event.repetitionText());
+ r = TQString::fromLatin1("%1 / %2").arg(event.recurrenceText()).arg(event.repetitionText());
else
r = event.recurrenceText();
- return i18n("&Recurrence - [%1]").tqarg(r);
+ return i18n("&Recurrence - [%1]").arg(r);
}
// Collect these widget labels together to ensure consistent wording and
@@ -295,8 +295,8 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
tqlayout->addWidget(mTemplateTimeGroup);
grid = new TQGridLayout(mTemplateTimeGroup, 2, 2, marginHint(), spacingHint());
grid->addRowSpacing(0, fontMetrics().lineSpacing()/2);
- // Get tqalignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
- int tqalignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
+ // Get alignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
+ int alignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
mTemplateDefaultTime = new RadioButton(i18n("&Default time"), mTemplateTimeGroup, "templateDefTimeButton");
mTemplateDefaultTime->setFixedSize(mTemplateDefaultTime->sizeHint());
@@ -304,7 +304,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
TQWhatsThis::add(mTemplateDefaultTime,
i18n("Do not specify a start time for alarms based on this template. "
"The normal default start time will be used."));
- grid->addWidget(mTemplateDefaultTime, 0, 0, tqalignment);
+ grid->addWidget(mTemplateDefaultTime, 0, 0, alignment);
TQHBox* box = new TQHBox(mTemplateTimeGroup);
box->setSpacing(spacingHint());
@@ -318,18 +318,18 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
mTemplateTime->setFixedSize(mTemplateTime->sizeHint());
mTemplateTime->setReadOnly(mReadOnly);
TQWhatsThis::add(mTemplateTime,
- TQString("%1\n\n%2").tqarg(i18n("Enter the start time for alarms based on this template."))
- .tqarg(TimeSpinBox::shiftWhatsThis()));
+ TQString("%1\n\n%2").arg(i18n("Enter the start time for alarms based on this template."))
+ .arg(TimeSpinBox::shiftWhatsThis()));
box->setStretchFactor(new TQWidget(box), 1); // left adjust the controls
box->setFixedHeight(box->sizeHint().height());
- grid->addWidget(box, 0, 1, tqalignment);
+ grid->addWidget(box, 0, 1, alignment);
mTemplateAnyTime = new RadioButton(i18n("An&y time"), mTemplateTimeGroup, "templateAnyTimeButton");
mTemplateAnyTime->setFixedSize(mTemplateAnyTime->sizeHint());
mTemplateAnyTime->setReadOnly(mReadOnly);
TQWhatsThis::add(mTemplateAnyTime,
- i18n("Set the '%1' option for alarms based on this template.").tqarg(i18n("Any time")));
- grid->addWidget(mTemplateAnyTime, 1, 0, tqalignment);
+ i18n("Set the '%1' option for alarms based on this template.").arg(i18n("Any time")));
+ grid->addWidget(mTemplateAnyTime, 1, 0, alignment);
box = new TQHBox(mTemplateTimeGroup);
box->setSpacing(spacingHint());
@@ -345,10 +345,10 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
mTemplateTimeAfter->setFixedSize(mTemplateTimeAfter->sizeHint());
mTemplateTimeAfter->setReadOnly(mReadOnly);
TQWhatsThis::add(mTemplateTimeAfter,
- TQString("%1\n\n%2").tqarg(AlarmTimeWidget::i18n_TimeAfterPeriod())
- .tqarg(TimeSpinBox::shiftWhatsThis()));
+ TQString("%1\n\n%2").arg(AlarmTimeWidget::i18n_TimeAfterPeriod())
+ .arg(TimeSpinBox::shiftWhatsThis()));
box->setFixedHeight(box->sizeHint().height());
- grid->addWidget(box, 1, 1, tqalignment);
+ grid->addWidget(box, 1, 1, alignment);
tqlayout->addStretch();
}
@@ -363,7 +363,7 @@ EditAlarmDlg::EditAlarmDlg(bool Template, const TQString& caption, TQWidget* par
static const TQString reminderText = i18n("Enter how long in advance of the main alarm to display a reminder alarm.");
mReminder = new Reminder(i18n("Rem&inder:"),
i18n("Check to additionally display a reminder in advance of the main alarm time(s)."),
- TQString("%1\n\n%2").tqarg(reminderText).tqarg(TimeSpinBox::shiftWhatsThis()),
+ TQString("%1\n\n%2").arg(reminderText).arg(TimeSpinBox::shiftWhatsThis()),
true, true, mainPage);
mReminder->setFixedSize(mReminder->sizeHint());
topLayout->addWidget(mReminder, 0, TQt::AlignAuto);
@@ -626,7 +626,7 @@ void EditAlarmDlg::initEmail(TQWidget* parent)
mEmailAttachList->setMinimumSize(mEmailAttachList->sizeHint());
mEmailAttachList->lineEdit()->setReadOnly(true);
TQListBox* list = mEmailAttachList->listBox();
-TQRect rect = list->tqgeometry();
+TQRect rect = list->geometry();
list->setGeometry(rect.left() - 50, rect.top(), rect.width(), rect.height());
label->setBuddy(mEmailAttachList);
TQWhatsThis::add(mEmailAttachList,
@@ -1424,7 +1424,7 @@ void EditAlarmDlg::slotOk()
mTabs->setCurrentPage(mMainPageIndex);
mReminder->setFocusOnCount();
KMessageBox::sorry(this, i18n("Reminder period must be less than the recurrence interval, unless '%1' is checked."
- ).tqarg(Reminder::i18n_first_recurrence_only()));
+ ).arg(Reminder::i18n_first_recurrence_only()));
return;
}
}
@@ -1479,15 +1479,15 @@ void EditAlarmDlg::slotTry()
if (mCommandRadio->isOn() && mCmdOutputGroup->selectedId() != EXEC_IN_TERMINAL)
{
theApp()->commandMessage((ShellProcess*)proc, this);
- KMessageBox::information(this, i18n("Command executed:\n%1").tqarg(text));
+ KMessageBox::information(this, i18n("Command executed:\n%1").arg(text));
theApp()->commandMessage((ShellProcess*)proc, 0);
}
else if (mEmailRadio->isOn())
{
TQString bcc;
if (mEmailBcc->isChecked())
- bcc = i18n("\nBcc: %1").tqarg(Preferences::emailBccAddress());
- KMessageBox::information(this, i18n("Email sent to:\n%1%2").tqarg(mEmailAddresses.join("\n")).tqarg(bcc));
+ bcc = i18n("\nBcc: %1").arg(Preferences::emailBccAddress());
+ KMessageBox::information(this, i18n("Email sent to:\n%1%2").arg(mEmailAddresses.join("\n")).arg(bcc));
}
}
}
@@ -1728,7 +1728,7 @@ bool EditAlarmDlg::checkEmailData()
if (!bad.isEmpty())
{
mEmailToEdit->setFocus();
- KMessageBox::error(this, i18n("Invalid email address:\n%1").tqarg(bad));
+ KMessageBox::error(this, i18n("Invalid email address:\n%1").arg(bad));
return false;
}
}
@@ -1752,7 +1752,7 @@ bool EditAlarmDlg::checkEmailData()
break; // empty
case -1:
mEmailAttachList->setFocus();
- KMessageBox::error(this, i18n("Invalid email attachment:\n%1").tqarg(att));
+ KMessageBox::error(this, i18n("Invalid email attachment:\n%1").arg(att));
return false;
}
}
@@ -2012,7 +2012,7 @@ bool EditAlarmDlg::checkText(TQString& result, bool showErrorMessage) const
default:
break;
}
- if (KMessageBox::warningContinueCancel(const_cast<EditAlarmDlg*>(this), errmsg.tqarg(alarmtext))
+ if (KMessageBox::warningContinueCancel(const_cast<EditAlarmDlg*>(this), errmsg.arg(alarmtext))
== KMessageBox::Cancel)
return false;
}